summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWilliam Hubbs <williamh@gentoo.org>2010-11-18 15:06:42 -0600
committerWilliam Hubbs <williamh@gentoo.org>2010-11-18 15:06:42 -0600
commit4ca32808dd6a9e73c12ec46b28d93b7d9db04fc7 (patch)
tree5afd352374a187661f3101fe3b6b9de0e8c89545
parent9e5b9abf407549e514d914e0f9d86df98d66fdf2 (diff)
downloadopenrc-4ca32808dd6a9e73c12ec46b28d93b7d9db04fc7.tar.gz
openrc-4ca32808dd6a9e73c12ec46b28d93b7d9db04fc7.tar.bz2
openrc-4ca32808dd6a9e73c12ec46b28d93b7d9db04fc7.tar.xz
Revert "allow ifplugd to work on wireless interfaces"
This reverts commit 4ea75dd1d6c1e475f103f027fd05861d237add4d. This caused a regression, see bug #345795. Ifplugd is only designed to support wireless interfaces that use the older wireless extentions.
-rw-r--r--net/ifplugd.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/net/ifplugd.sh b/net/ifplugd.sh
index 995fe81..5831720 100644
--- a/net/ifplugd.sh
+++ b/net/ifplugd.sh
@@ -27,8 +27,8 @@ ifplugd_pre_start()
return 0
fi
- # We don't work on bonded, bridges, tun/tap or vlan
- for f in bond bridge tuntap vlan; do
+ # We don't work on bonded, bridges, tun/tap, vlan or wireless
+ for f in bond bridge tuntap vlan wireless; do
if type "_is_${f}" >/dev/null 2>&1; then
if _is_${f}; then
veinfo "ifplugd does not work with ${f}"